@@ -1,3 +1,4 @@
+# pylint: disable=invalid-name
 # ======================================================================
 # ====================================
 # README file for Skew Correction component
@@ -59,11 +60,16 @@ from ocrd_models.ocrd_page import (
     MetadataItemType,
     LabelsType, LabelType
     )
-from ocrd_utils import getLogger, concat_padded, MIMETYPE_PAGE
+from ocrd_utils import (
+    getLogger,
+    concat_padded,
+    MIMETYPE_PAGE,
+    make_file_id,
+    assert_file_grp_cardinality
+)
 
 TOOL = 'ocrd-anybaseocr-deskew'
 LOG = getLogger('OcrdAnybaseocrDeskewer')
-FALLBACK_IMAGE_GRP = 'OCR-D-IMG-DESKEW'
 
 class OcrdAnybaseocrDeskewer(Processor):
 
@@ -88,12 +94,9 @@ class OcrdAnybaseocrDeskewer(Processor):
         return a
 
     def process(self):
-        try:
-            page_grp, self.image_grp = self.output_file_grp.split(',')
-        except ValueError:
-            page_grp = self.output_file_grp
-            self.image_grp = FALLBACK_IMAGE_GRP
-            LOG.info("No output file group for images specified, falling back to '%s'", FALLBACK_IMAGE_GRP)
+        assert_file_grp_cardinality(self.input_file_grp, 1)
+        assert_file_grp_cardinality(self.output_file_grp, 1)
+
         oplevel = self.parameter['operation_level']
 
         for (n, input_file) in enumerate(self.input_files):
@@ -123,19 +126,14 @@ class OcrdAnybaseocrDeskewer(Processor):
                 LOG.warning('Operation level %s, but should be "page".', oplevel)
                 break
             
-            # Use input_file's basename for the new file -
-            # this way the files retain the same basenames:
-            file_id = input_file.ID.replace(self.input_file_grp, page_grp)
-            if file_id == input_file.ID:
-                file_id = concat_padded(page_grp, n)
-            
+            file_id = make_file_id(input_file, self.output_file_grp)
+            pcgts.set_pcGtsId(file_id)
             self.workspace.add_file(
                 ID=file_id,
-                file_grp=page_grp,
+                file_grp=self.output_file_grp,
                 pageId=input_file.pageId,
-                mimetype=MIMETYPE_PAGE,                
-                local_filename=os.path.join(page_grp,
-                                            file_id + '.xml'),
+                mimetype=MIMETYPE_PAGE,
+                local_filename=os.path.join(self.output_file_grp, file_id + '.xml'),
                 content=to_xml(pcgts).encode('utf-8')
             )
     
@@ -215,13 +213,11 @@ class OcrdAnybaseocrDeskewer(Processor):
         bin_array = array(255*(deskewed>ocrolib.midrange(deskewed)),'B')
         page_image = ocrolib.array2pil(bin_array)
         
-        file_id = input_file.ID.replace(self.input_file_grp, self.image_grp)
-        if file_id == input_file.ID:
-            file_id = concat_padded(self.image_grp, n)
+        file_id = make_file_id(input_file, self.output_file_grp)
         file_path = self.workspace.save_image_file(page_image,
-                               file_id,
+                               file_id + '-IMG',
                                page_id=page_id,
-                               file_grp=self.image_grp
+                               file_grp=self.output_file_grp
         )        
         page.add_AlternativeImage(AlternativeImageType(filename=file_path, comments=page_xywh['features']))
         
