@@ -16,7 +16,7 @@ from ocrd_models.ocrd_page import (
     MetadataItemType,
     LabelsType, LabelType
 )
-from ocrd_utils import getLogger
+from ocrd_utils import getLogger, assert_file_grp_cardinality
 from ocrd_models import ocrd_mets
 
 from pathlib import Path
@@ -211,6 +211,8 @@ class OcrdAnybaseocrLayoutAnalyser(Processor):
         if not tf.test.is_gpu_available():
             LOG.error("Your system has no CUDA installed. No GPU detected.")
             # sys.exit(1)
+        assert_file_grp_cardinality(self.input_file_grp, 1)
+        assert_file_grp_cardinality(self.output_file_grp, 1)
         model_path = Path(self.parameter['model_path'])
         class_mapper_path = Path(self.parameter['class_mapping_path'])
         if not Path(model_path).is_file():
